@@ -13,8 +13,8 @@ void WrPlugin::initInterface(MainWindow *parent) {
     sink = new WrSink(this);
     sink->setPlugin(this);
     connect(parent, SIGNAL(barcodeAnalysedSignal(QString,QString)),
-            sink, SLOT(barcodeAnalysed(QString,QString)));
-
+            this, SLOT(barcodeAnalysed(QString,QString)));
+    barcodeText = "No barcode analysed yet";
     int size = settings->beginReadArray("searchProviders");
     for(int i = 0; i < size; i++) {
         settings->setArrayIndex(i);
@@ -50,6 +50,11 @@ void WrPlugin::setSearchProviders(QList<SearchProvider*> providers) {
     saveSearchProviders();
 }
 
+void WrPlugin::barcodeAnalysed(QString barcodeType, QString barcodeData) {
+    qDebug() << "WrPlugin::barcodeAnalysed() recieved analysed signal" << barcodeData;
+    barcodeText = barcodeData;
+}
+
 void WrPlugin::saveSearchProviders() {
     settings->beginWriteArray("searchProviders");
     for(int i = 0; i < providers.size(); i++) {
